@@ -42,6 +42,7 @@ class ObjDict(dict):
 
 
 default_sso_settings = {
+    "CONFIRM_USERNAME": "email",
     "WORK_MODE": "standalone",
     "DEBUG_MODE": False,
     "DEBUG_KEY": "1111",
@@ -78,6 +79,7 @@ default_sso_settings = {
     "SERIALIZERS": ObjDict({
         "USER_RETURN_SERIALIZER": "drf_auth_service.users.serializers.ReturnUserBaseSerializer",
         "USER_SERIALIZER": "drf_auth_service.users.serializers.UserBaseSerializer",
+        "USER_IDENTIFIER": "drf_auth_service.users.serializers.UserIdentifierSerializer",
         "BLOCK_USER_SERIALIZER": "drf_auth_service.users.serializers.BlockUserSerializer",
         "USER_CONFIRM_SERIALIZER": "drf_auth_service.users.serializers.UserConfirmSerializer",
         "SOCIAL_RETURN_SERIALIZER": "drf_auth_service.socials.serializers.ReturnSocialSerializer",
@@ -129,7 +131,8 @@ HTML_EMAIL_REQUIRED_CONFIGS = ["HTML_RESET_PASSWORD_SUBJECT", "HTML_CONFIRMATION
 TWILIO_REQUIRED_CONFIGS = ["TWILIO_ACCOUNT_SID", "TWILIO_AUTH_TOKEN", "TWILIO_FROM_NUMBER"]
 
 SETTINGS_TO_IMPORT_IN_DB = ["BACKENDS", "REGISTER_TYPES", "SEND_CONFIRMATION", "SMS_RESET_PASSWORD_MESSAGE",
-                            "SMS_CONFIRMATION_MESSAGE", "DEBUG_MODE", "DEBUG_KEY"] + SENDINBLUE_REQUIRED_CONFIGS \
+                            "SMS_CONFIRMATION_MESSAGE", "DEBUG_MODE", "DEBUG_KEY", "CONFIRM_USERNAME"] \
+                           + SENDINBLUE_REQUIRED_CONFIGS \
                            + MAILCHIMP_REQUIRED_CONFIGS + HTML_EMAIL_REQUIRED_CONFIGS + TWILIO_REQUIRED_CONFIGS
 
 PHONE_NUMBER_BACKEND_CASE = []
