@@ -2,11 +2,15 @@ from rest_framework import serializers
 
 from drf_auth_service.models import ActivationCode
 from drf_auth_service.services.serializers import ServiceSerializer
-from drf_auth_service.settings import User
+from drf_auth_service.settings import User, settings
 from drf_auth_service.socials.serializers import SocialModelSerializer
 from drf_auth_service.validators import validate_token_by_type
 
 
+class UserIdentifierSerializer(serializers.Serializer): # noqa
+    username = serializers.CharField(required=True)
+
+
 class UserBaseSerializer(serializers.ModelSerializer):
     class Meta:
         model = User
@@ -22,7 +26,7 @@ class ReturnUserBaseSerializer(serializers.ModelSerializer):
         fields = ('id', 'username', 'service', 'is_blocked', 'user_social_identifier', 'is_confirmed')
 
 
-class UserConfirmSerializer(serializers.Serializer): # noqa
+class UserConfirmSerializer(serializers.Serializer):  # noqa
     token = serializers.CharField(required=True, allow_null=False, allow_blank=False,
                                   label="Token to confirm user")
 
@@ -30,11 +34,11 @@ class UserConfirmSerializer(serializers.Serializer): # noqa
         return validate_token_by_type(
             token,
             ActivationCode.CodeTypes.CONFIRM_ACCOUNT,
-            username=self.context['request'].parser_context['kwargs']['username']
+            **{settings.CONFIRM_USERNAME: self.context['request'].parser_context['kwargs']['username']}
         )
 
 
-class UserSetPasswordSerializer(serializers.Serializer): # noqa
+class UserSetPasswordSerializer(UserIdentifierSerializer):  # noqa
     password = serializers.CharField(label="Password", required=True, allow_null=False, allow_blank=False)
     confirm_password = serializers.CharField(label="Confirm password", required=True,
                                              allow_null=False, allow_blank=False)
@@ -46,5 +50,5 @@ class UserSetPasswordSerializer(serializers.Serializer): # noqa
         return data
 
 
-class BlockUserSerializer(serializers.Serializer): # noqa
+class BlockUserSerializer(UserIdentifierSerializer):  # noqa
     reason = serializers.CharField(required=True)
